//-*-Mode: C++;-*-
/***************************************************************************
                          settingsignals.h  -  description
                             -------------------
    begin                : Sun Oct 1 2000
    copyright            : (C) 2000 by Rajko Albrecht
    email                : Rajko.Albrecht@informatik.tu-chemnitz.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef SETTINGSIGNALS_H
#define SETTINGSIGNALS_H

#include <qobject.h>

/**
  *@author Rajko Albrecht
  */
class Settingsignals:public QObject
{
    Q_OBJECT
public:
    Settingsignals(){}
    virtual ~Settingsignals(){}
    void make_settings_changed_signal(){emit settingsChanged();}

signals:
    void npropfont_changed();
    void fixfont_changed();
    void threadtimer_changed(int);
    void statustimer_changed(int);
    void settingsChanged();

protected:
    void make_f_font_signal(){emit fixfont_changed();}
    void make_np_font_signal(){emit npropfont_changed();}
    void make_thread_signal(int aValue){emit threadtimer_changed(aValue);}
    void make_status_signal(int aValue){emit statustimer_changed(aValue);}
};

#endif
